@@ -27,7 +27,7 @@ class ProviderSwitchHandler(object):
 
     def _prepare(self) -> None:
         providers = ProviderCollection(
-            driver_type='json', social_type=self.social_type, service_name=self.service_name).get_providers()
+            driver_type='ssm', social_type=self.social_type, service_name=self.service_name).get_providers()
         if self.allowed_providers is not None:
             providers = [provider for provider in providers if provider.name in self.allowed_providers]
 
